@@ -317,6 +317,7 @@ static void osinfo_loader_device(OsinfoLoader *loader,
         OSINFO_DEVICE_PROP_VENDOR_ID,
         OSINFO_DEVICE_PROP_PRODUCT,
         OSINFO_DEVICE_PROP_PRODUCT_ID,
+        OSINFO_DEVICE_PROP_SUBSYSTEM,
         OSINFO_DEVICE_PROP_BUS_TYPE,
         OSINFO_DEVICE_PROP_CLASS,
         OSINFO_DEVICE_PROP_NAME,
@@ -619,7 +620,7 @@ static void osinfo_loader_install_script(OsinfoLoader *loader,
         goto error;
     if (value)
         osinfo_entity_set_param(OSINFO_ENTITY(installScript),
-                                OSINFO_INSTALL_SCRIPT_PROP_OUTPUT_FILENAME,
+                                OSINFO_INSTALL_SCRIPT_PROP_EXPECTED_FILENAME,
                                 value);
     g_free(value);
 
@@ -651,6 +652,8 @@ static OsinfoMedia *osinfo_loader_media (OsinfoLoader *loader,
     gchar *arch = (gchar *)xmlGetProp(root, BAD_CAST "arch");
     xmlChar *live = xmlGetProp(root, BAD_CAST OSINFO_MEDIA_PROP_LIVE);
     xmlChar *installer = xmlGetProp(root, BAD_CAST OSINFO_MEDIA_PROP_INSTALLER);
+    xmlChar *installer_reboots =
+            xmlGetProp(root, BAD_CAST OSINFO_MEDIA_PROP_INSTALLER_REBOOTS);
     const gchar *const keys[] = {
         OSINFO_MEDIA_PROP_URL,
         OSINFO_MEDIA_PROP_KERNEL,
@@ -675,6 +678,13 @@ static OsinfoMedia *osinfo_loader_media (OsinfoLoader *loader,
         xmlFree(installer);
     }
 
+    if (installer_reboots) {
+        osinfo_entity_set_param(OSINFO_ENTITY(media),
+                                OSINFO_MEDIA_PROP_INSTALLER_REBOOTS,
+                                (gchar *)installer_reboots);
+        xmlFree(installer_reboots);
+    }
+
     gint nnodes = osinfo_loader_nodeset("./iso/*", ctxt, &nodes, err);
     if (error_is_set(err))
         return NULL;
@@ -1482,7 +1492,6 @@ void osinfo_loader_process_default_path(OsinfoLoader *loader, GError **err)
     return;
 
  error:
-    g_print("Fail\n");
     g_propagate_error(err, error);
     return;
 }
