@@ -70,16 +70,17 @@ typedef struct _OsinfoMediaClass   OsinfoMediaClass;
 
 typedef struct _OsinfoMediaPrivate OsinfoMediaPrivate;
 
-#define OSINFO_MEDIA_PROP_ARCHITECTURE "architecture"
-#define OSINFO_MEDIA_PROP_URL          "url"
-#define OSINFO_MEDIA_PROP_VOLUME_ID    "volume-id"
-#define OSINFO_MEDIA_PROP_SYSTEM_ID    "system-id"
-#define OSINFO_MEDIA_PROP_PUBLISHER_ID "publisher-id"
+#define OSINFO_MEDIA_PROP_ARCHITECTURE   "architecture"
+#define OSINFO_MEDIA_PROP_URL            "url"
+#define OSINFO_MEDIA_PROP_VOLUME_ID      "volume-id"
+#define OSINFO_MEDIA_PROP_SYSTEM_ID      "system-id"
+#define OSINFO_MEDIA_PROP_PUBLISHER_ID   "publisher-id"
 #define OSINFO_MEDIA_PROP_APPLICATION_ID "application-id"
-#define OSINFO_MEDIA_PROP_KERNEL       "kernel"
-#define OSINFO_MEDIA_PROP_INITRD       "initrd"
-#define OSINFO_MEDIA_PROP_LIVE         "live"
-#define OSINFO_MEDIA_PROP_INSTALLER    "installer"
+#define OSINFO_MEDIA_PROP_KERNEL         "kernel"
+#define OSINFO_MEDIA_PROP_INITRD         "initrd"
+#define OSINFO_MEDIA_PROP_LIVE           "live"
+#define OSINFO_MEDIA_PROP_INSTALLER      "installer"
+#define OSINFO_MEDIA_PROP_INSTALLER_REBOOTS "installer-reboots"
 
 /* object */
 struct _OsinfoMedia
@@ -124,6 +125,7 @@ const gchar *osinfo_media_get_kernel_path(OsinfoMedia *media);
 const gchar *osinfo_media_get_initrd_path(OsinfoMedia *media);
 gboolean osinfo_media_get_installer(OsinfoMedia *media);
 gboolean osinfo_media_get_live(OsinfoMedia *media);
+gint osinfo_media_get_installer_reboots(OsinfoMedia *media);
 
 #endif /* __OSINFO_MEDIA_H__ */
 /*
