@@ -76,6 +76,7 @@ enum {
     PROP_VENDOR,
     PROP_VERSION,
     PROP_CODENAME,
+    PROP_LOGO,
 };
 
 static void osinfo_product_link_free(gpointer data, gpointer opaque G_GNUC_UNUSED)
@@ -130,6 +131,9 @@ osinfo_product_get_property (GObject    *object,
     case PROP_CODENAME:
         g_value_set_string (value,
                             osinfo_product_get_codename (product));
+    case PROP_LOGO:
+        g_value_set_string (value,
+                            osinfo_product_get_logo (product));
         break;
 
     default:
@@ -224,6 +228,21 @@ osinfo_product_class_init (OsinfoProductClass *klass)
                                  G_PARAM_STATIC_NICK |
                                  G_PARAM_STATIC_BLURB);
     g_object_class_install_property (g_klass, PROP_NAME, pspec);
+
+    /**
+     * OsinfoProduct::logo:
+     *
+     * The URI of the logo of the product.
+     */
+    pspec = g_param_spec_string ("logo",
+                                 "Logo",
+                                 "URI of the logo",
+                                 NULL /* default value */,
+                                 G_PARAM_READABLE |
+                                 G_PARAM_STATIC_NAME |
+                                 G_PARAM_STATIC_NICK |
+                                 G_PARAM_STATIC_BLURB);
+    g_object_class_install_property (g_klass, PROP_LOGO, pspec);
 }
 
 static void
@@ -354,7 +373,10 @@ GDate *osinfo_product_get_eol_date(OsinfoProduct *prod)
     return date_from_string(str);
 }
 
-
+const gchar *osinfo_product_get_logo(OsinfoProduct *prod)
+{
+    return osinfo_entity_get_param_value(OSINFO_ENTITY(prod), OSINFO_PRODUCT_PROP_LOGO);
+}
 
 /*
  * Local variables:
